Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Environment HostEnvironment K8SClient client.Client K8SClientset *kubernetes.Clientset HPK endpoint.HPKPath )
var ( ReasonObjectNotFound = "ObjectNotFound" ReasonSpecError = "SpecError" ReasonUnsupportedFeatures = "UnsupportedFeatures" ReasonExecutionError = "ExecutionError" ReasonInitializationError = "InitializationError" )
var ( ErrUnboundedPVC = errors.New("unbound pvc") ErrUnsupportedClaimMode = errors.New("hpk does not support block volume provisioning") )
Volume Errors
var (
DefaultLogger = zap.New(zap.UseDevMode(true))
)
Instantiated Types
Functions ¶
func SystemPanic ¶
Types ¶
type HostEnvironment ¶ added in v0.1.2
type HostEnvironment struct {
KubeMasterHost string
ContainerRegistry string
ApptainerBin string
EnableCgroupV2 bool
WorkingDirectory string
// KubeDNS points to the internal DNS of a Kubernetes cluster.
KubeDNS string
}
HostEnvironment containers information about the execution environment.
type VirtualEnvironment ¶ added in v0.1.2
type VirtualEnvironment struct {
// PodDirectory points to the pod directory on the underlying filesystem.
PodDirectory string
// CgroupFilePath points to the cgroup configuration for the virtual environment.
CgroupFilePath string
// ConstructorFilePath points to the script for creating the virtual environment for Pod.
ConstructorFilePath string
// IPAddressPath is where we store the internal Pod's ip.
IPAddressPath string
// StdoutPath instruct Slurm to write stdout into the specified path.
StdoutPath string
// StdoutPath instruct Slurm to write stderr into the specified path.
StderrPath string
// SysErrorFilePath indicate a system failure that cause the Pod to fail Immediately, bypassing any other checks.
SysErrorFilePath string
}
The VirtualEnvironment create lightweight "virtual environments" that resemble "Pods" semantics.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package job contains code for accessing compute resources via Slurm.
|
Package job contains code for accessing compute resources via Slurm. |
|
configmap
Package configmap contains the internal representation of configMap volumes.
|
Package configmap contains the internal representation of configMap volumes. |
|
emptydir
Package emptydir contains the internal representation of emptyDir volumes.
|
Package emptydir contains the internal representation of emptyDir volumes. |
|
hostpath
Package hostpath contains the internal representation of hostPath volumes.
|
Package hostpath contains the internal representation of hostPath volumes. |
|
secret
Package secret contains the internal representation of secret volumes.
|
Package secret contains the internal representation of secret volumes. |
Click to show internal directories.
Click to hide internal directories.