Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var NotFoundBackoff = wait.Backoff{ Steps: 4, Duration: 2 * time.Second, Factor: 5.0, Jitter: 0.1, }
NotFoundBackoff is the recommended backoff for a resource that is required, but is not created yet. For instance, when mounting configmap volumes to pods. TODO: in future version, the backoff can be self-modified depending on the load of the controller.
Functions ¶
This section is empty.
Types ¶
type Attributes ¶
Attributes represents the attributes of this mounter.
type MounterArgs ¶
type MounterArgs struct {
// When FsUser is set, the ownership of the volume will be modified to be
// owned and writable by FsUser. Otherwise, there is no side effects.
// Currently only supported with projected service account tokens.
FsUser *int64
FsGroup *int64
FSGroupChangePolicy *corev1.PodFSGroupChangePolicy
DesiredSize *resource.Quantity
SELinuxLabel string
}
MounterArgs provides more easily extensible arguments to Mounter
Directories
¶
| Path | Synopsis |
|---|---|
|
Package configmap contains the internal representation of configMap volumes.
|
Package configmap contains the internal representation of configMap volumes. |
|
Package emptydir contains the internal representation of emptyDir volumes.
|
Package emptydir contains the internal representation of emptyDir volumes. |
|
Package hostpath contains the internal representation of hostPath volumes.
|
Package hostpath contains the internal representation of hostPath volumes. |
|
Package secret contains the internal representation of secret volumes.
|
Package secret contains the internal representation of secret volumes. |
Click to show internal directories.
Click to hide internal directories.